/*
 * Matrix is | a  b  0|
 *           | c  d  0|
 *           |tX tY  1|
 *
 * expressed in APIs as a vector [a b c d tX tY] 
 *
 * Transformations occur via
 *                               x' = ax + cy + tX
 *                               y' = by + dx + tY
 */

/*
 * Oddities with screen fonts.
 *
 * OSX it seems does not care.
 *
 * OPENSTEP 4.2 really needs non-screen fonts for the matrix manipulations,
 * otherwise wierd output results - I guess there is no general support for
 * the matrix manipulation using screen fonts on OPENSTEP.
 *
 * GS art wants non-screen fonts in order for 'reversed' characters to generate
 * correct output - i.e the matrix [-W 0 0 H 0 0] which flips a character from
 * left to right (reflect throught a vertical axis mirror).  Using screen
 * fonts results in odd word layout,  i.e. 'Backward letter text.' becomes
 * "rettel drawkcaB           .txet' rather than ".txet rettel drawkcaB'.
 */
#undef USE_SCREEN_FONTS

/*
 * On OPENSTEP, the window is too small to show all out the complete output,
 * so allow part to be omitted at compile time.
 */
#undef NO_SLOPE_ROTATE


			/* RESULTS */

/* OPENSTEP - general
 *
 * It appears as if the transforms were only really tested in a flipped view,
 * as it is largely correct,  with the normal view exihibiting instances of
 * flipped text for uncommon transforms (anything other than radio preserving
 * scaling).
 */

/* OPENSTEP - flipped view
 *
 * Normal, scaled height, scaled width, equal ratio scaled height+width correct.
 * Oblique left and Oblique right correct.
 * Inverted letters ineffective - they stay upright.
 * Translating baseline to generate superscript gives subscript.
 * Vertically flipped characters work but also inverted (i.e flipped down).
 * Vertical text lay out in a horizontal baseline, using the available line
 * height for as many chars as will stack,  and translation indicies
 * have an effect,  but X&Y seem swapped.  Without translation the letters
 * overlay each other.
 * Backward letters appear when centered,  left aligned shows first letter,
 * right aligned last character,  suggesting the bounds of the string are
 * miscalculated relative to the movement direction.   Note that the sentance
 * is in effect mirrored,  rather than individual letters being mirrored,.
 * The backward letters have correct orientation (not flipped).
 * Sloped and rotated text is upright.  Sloped text slopes the wrong way,
 * and fills horizontally within the line height,  so it occasionally breaks
 * within words. Rotated text leans the correct way,  but baseline slopes
 * down (rather than up or straight),  so the effect is incorrect.
 */
 
/* OPENSTEP - normal view
 *
 * Normal, equal ratio scaled height+width correct.
 * Scaled height, scaled width are flipped as well as scaled.
 * Oblique left and right are flipped and so appear to lean the wrong way;
 * the top of the letter (bottom of the image) is on the wrong side.
 * Inverted letters ineffective - they stay upright.
 * Translating baseline to generate superscript works,  but superscript
 * text is also flipped.
 * Vertically flipped characters work as in flipped view,  but here they
 * have the correct orientation - i.e. not flipped.
 * Vertical text stays in a horizontal baseline,  and translation indicies
 * have an effect,  but X&Y seem swapped.
 * Backward letters as in flipped view,  but here they are flipped.
 * Sloped and rotated text flipped,  and both baselines slope up.
 * Otherwise as for flipped view.  So it would be almost correct if the
 * chars were not flipped.
 */
 
/* GNUstep - Cairo backend - normal view.
 *
 * Generally looks good,  with a few exceptions.
 * Obliqued text leans the wrong way.
 * Sloped and Rotated text and angled down rather than up.
 * Vertically rotated text progresses down rather than up.
 * Translating the baseline up,  actually goes down.
 * Hence there seems to be a general issue of direction of rotation -
 * i.e. the sign on matrix elements 'b', 'c' and 'tY'.
 */
